# Localizer
A library focused on easily translating the strings of an application in different languages.

The library is easy to use and has auto-translating features.

To see examples of using the library inspect the "examples.py" file.